==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/OptionBPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.OptionBPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Option B configuration.
 * @property exportRouteTargets Route Targets to be applied for outgoing routes from CE.
 * @property importRouteTargets Route Targets to be applied for incoming routes into CE.
 */
public data class OptionBPropertiesArgs(
    public val exportRouteTargets: Output<List<String>>? = null,
    public val importRouteTargets: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.OptionBPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.managednetworkfabric.inputs.OptionBPropertiesArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.OptionBPropertiesArgs.builder()
            .exportRouteTargets(exportRouteTargets?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .importRouteTargets(
                importRouteTargets?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [OptionBPropertiesArgs].
 */
@PulumiTagMarker
public class OptionBPropertiesArgsBuilder internal constructor() {
    private var exportRouteTargets: Output<List<String>>? = null

    private var importRouteTargets: Output<List<String>>? = null

    /**
     * @param value Route Targets to be applied for outgoing routes from CE.
     */
    @JvmName("akvihdmxwbviaovf")
    public suspend fun exportRouteTargets(`value`: Output<List<String>>) {
        this.exportRouteTargets = value
    }

    @JvmName("noingsvyahaiiang")
    public suspend fun exportRouteTargets(vararg values: Output<String>) {
        this.exportRouteTargets = Output.all(values.asList())
    }

    /**
     * @param values Route Targets to be applied for outgoing routes from CE.
     */
    @JvmName("pqdcuyvlfrmptwwp")
    public suspend fun exportRouteTargets(values: List<Output<String>>) {
        this.exportRouteTargets = Output.all(values)
    }

    /**
     * @param value Route Targets to be applied for incoming routes into CE.
     */
    @JvmName("jaohgvmeqltkdjkw")
    public suspend fun importRouteTargets(`value`: Output<List<String>>) {
        this.importRouteTargets = value
    }

    @JvmName("cnmjmfxmtamvjsgc")
    public suspend fun importRouteTargets(vararg values: Output<String>) {
        this.importRouteTargets = Output.all(values.asList())
    }

    /**
     * @param values Route Targets to be applied for incoming routes into CE.
     */
    @JvmName("foyoqcxmobqleqor")
    public suspend fun importRouteTargets(values: List<Output<String>>) {
        this.importRouteTargets = Output.all(values)
    }

    /**
     * @param value Route Targets to be applied for outgoing routes from CE.
     */
    @JvmName("emjdjihudorejacm")
    public suspend fun exportRouteTargets(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exportRouteTargets = mapped
    }

    /**
     * @param values Route Targets to be applied for outgoing routes from CE.
     */
    @JvmName("kmjboeqbphsicskw")
    public suspend fun exportRouteTargets(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exportRouteTargets = mapped
    }

    /**
     * @param value Route Targets to be applied for incoming routes into CE.
     */
    @JvmName("llsodudqxfwxlrdy")
    public suspend fun importRouteTargets(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.importRouteTargets = mapped
    }

    /**
     * @param values Route Targets to be applied for incoming routes into CE.
     */
    @JvmName("fuaxrjqnnfprudah")
    public suspend fun importRouteTargets(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.importRouteTargets = mapped
    }

    internal fun build(): OptionBPropertiesArgs = OptionBPropertiesArgs(
        exportRouteTargets = exportRouteTargets,
        importRouteTargets = importRouteTargets,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/OptionBPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.OptionBPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Option B configuration.
 * @property exportRouteTargets Route Targets to be applied for outgoing routes from CE.
 * @property importRouteTargets Route Targets to be applied for incoming routes into CE.
 */
public data class OptionBPropertiesArgs(
    public val exportRouteTargets: Output<List<String>>? = null,
    public val importRouteTargets: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.OptionBPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.managednetworkfabric.inputs.OptionBPropertiesArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.OptionBPropertiesArgs.builder()
            .exportRouteTargets(exportRouteTargets?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .importRouteTargets(
                importRouteTargets?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [OptionBPropertiesArgs].
 */
@PulumiTagMarker
public class OptionBPropertiesArgsBuilder internal constructor() {
    private var exportRouteTargets: Output<List<String>>? = null

    private var importRouteTargets: Output<List<String>>? = null

    /**
     * @param value Route Targets to be applied for outgoing routes from CE.
     */
    @JvmName("rqcxrctoplhochqw")
    public suspend fun exportRouteTargets(`value`: Output<List<String>>) {
        this.exportRouteTargets = value
    }

    @JvmName("rempfobxcoppbipi")
    public suspend fun exportRouteTargets(vararg values: Output<String>) {
        this.exportRouteTargets = Output.all(values.asList())
    }

    /**
     * @param values Route Targets to be applied for outgoing routes from CE.
     */
    @JvmName("lavvipbltesgbxhs")
    public suspend fun exportRouteTargets(values: List<Output<String>>) {
        this.exportRouteTargets = Output.all(values)
    }

    /**
     * @param value Route Targets to be applied for incoming routes into CE.
     */
    @JvmName("syxmjfesvshomdha")
    public suspend fun importRouteTargets(`value`: Output<List<String>>) {
        this.importRouteTargets = value
    }

    @JvmName("sjtgphyjbdchuqac")
    public suspend fun importRouteTargets(vararg values: Output<String>) {
        this.importRouteTargets = Output.all(values.asList())
    }

    /**
     * @param values Route Targets to be applied for incoming routes into CE.
     */
    @JvmName("dwfaoeoudbxecqat")
    public suspend fun importRouteTargets(values: List<Output<String>>) {
        this.importRouteTargets = Output.all(values)
    }

    /**
     * @param value Route Targets to be applied for outgoing routes from CE.
     */
    @JvmName("fvwldntovnmxcgbp")
    public suspend fun exportRouteTargets(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exportRouteTargets = mapped
    }

    /**
     * @param values Route Targets to be applied for outgoing routes from CE.
     */
    @JvmName("rculwdpafeemnwdh")
    public suspend fun exportRouteTargets(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exportRouteTargets = mapped
    }

    /**
     * @param value Route Targets to be applied for incoming routes into CE.
     */
    @JvmName("xglnoahefuhmxrtg")
    public suspend fun importRouteTargets(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.importRouteTargets = mapped
    }

    /**
     * @param values Route Targets to be applied for incoming routes into CE.
     */
    @JvmName("pamaqlhsbywahuyb")
    public suspend fun importRouteTargets(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.importRouteTargets = mapped
    }

    internal fun build(): OptionBPropertiesArgs = OptionBPropertiesArgs(
        exportRouteTargets = exportRouteTargets,
        importRouteTargets = importRouteTargets,
    )
}
